<?php if(!defined('ABSPATH')) exit; ?>
<?php
add_action('save_post', 'sfr_meta_boxes');

function sfr_meta_boxes($post_id) {
	global $meta_box;

	if (isset($_POST['sfr_metabox_nonce']) && !wp_verify_nonce($_POST['sfr_metabox_nonce'], basename(__FILE__))) {
		return $post_id;
	}

	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return $post_id;
	}

	if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
		if (!current_user_can('edit_page', $post_id)) {
			return $post_id;
		}
	} elseif (!current_user_can('edit_post', $post_id)) {
		return $post_id;
	}

	if(is_array($meta_box['fields'] )) {
		foreach ($meta_box['fields'] as $field) {
			$old = get_post_meta($post_id, $field['id'], true);
			$new = $_POST[$field['id']];

			if ($new && $new != $old) {
				update_post_meta($post_id, $field['id'], $new);
			} elseif ('' == $new && $old) {
				delete_post_meta($post_id, $field['id'], $old);
			}
		}
	}
}

function safir_post_meta_boxes() {

	$meta_boxes = array(
		array(
			"name" => "sliderImage",
			"title" => '<b>Manşet görsel alanı</b><br/>Bu alana ekleyeceğiniz resim, ana manşet bileşeninde kullanılacaktır, eğer eklemezseniz yazıdaki öne çıkarılan görsel kullanılır. Hareketli gif dosyası kullanabilirsiniz. Manşet görsellerinin aynı boyutta/oranda olması tavsiye edilir, önerilen görsel boyutu: 825x450',
			"type" => "image"
		),
		array(
			"name" => "wideSliderImage",
			"title" => '<b>Geniş manşet bileşeni görsel alanı</b><br/>Bu alana ekleyeceğiniz resim, geniş manşet bileşeninde kullanılacaktır. Bu bileşeni kullanmıyorsanız bu alanı boş bırakabilirsiniz. Hareketli gif dosyası kullanabilirsiniz. Manşet görsellerinin aynı boyutta olması tavsiye edilir, resim genişliği 1070px olmalı, yüksekliği ise tüm görsellerde aynı olmak kaydıyla istediğiniz gibi ayarlayabilirsiniz. Bileşen içinde yükseklik değerini değiştirebilirsiniz.',
			"type" => "image"
		),
		array(
			"name" => "galleryType",
			"title" => 'Galeri tipini seçiniz',
			"type" => "select",
			"options" => array("Varsayılan", "Tip 1 - Sayfa içi galeri", "Tip 2 - Ayrı sayfada açılan galeri"),
			"values" => array("default", "type1", "type2"),
		),
	);
	return apply_filters( "safir_post_meta_boxes", $meta_boxes );
}

function post_meta_boxes() {
	global $post;
	$meta_boxes = safir_post_meta_boxes( );
	?>
	<table class="form-table" style="overflow:hidden">
	<?php
	$counter = 0;
	foreach ( $meta_boxes as $meta )
	{
		$counter++;
		if($counter%2 == 1) echo '<tr>';
		$value = get_post_meta( $post->ID, $meta['name'], true );
		if ( $meta['type'] == "text" )
		{
			get_meta_text_input( $meta, $value );
		} elseif ( $meta['type'] == "select" ) {
			get_meta_text_select( $meta, $value );
		} elseif ( $meta['type'] == "image" ) {
			get_meta_text_image( $meta, $value );
		} elseif ( $meta['type'] == "textarea" ) {
			get_meta_text_textarea( $meta, $value );
		} elseif ( $meta['type'] == "maps" ) {
			get_meta_text_maps( $meta, $value );
		}
		if($counter%2 == 0) echo '</tr>';
	}
	?>
	</table>
	<?php
}

function get_meta_text_input( $args = array( ), $value = false ) {
	extract( $args );
	?>
	<div class="safir-metabox-item" style="margin-bottom: 20px; background:#fafafa; border:1px solid #ddd; padding: 15px">
		<p style="margin:0; font-size:13px">
		<label for="<?php echo $name; ?>"><?php echo $title; ?></label>
		</p>
		<p>
		<input type="text" name="<?php echo $name; ?>" id="<?php echo $name; ?>" value="<?php echo esc_html( $value )?>" tabindex="30" style="display:block; width:100%" />
		<input type="hidden" name="<?php echo $name . '_noncename';?>" id="<?php echo $name . '_noncename';?>" value="<?php echo wp_create_nonce( plugin_basename(__FILE__) );?>" />
		</p>
	</div>
<?php
}


function get_meta_text_select( $args = array( ), $value = false )
{
	extract( $args );
	?>
	<div class="safir-metabox-item" style="margin-bottom: 20px; background:#fafafa; border:1px solid #ddd; padding: 15px">
		<?php echo $title ?>
			<select name="<?php echo $name; ?>" id="<?php echo $name; ?>">
			<?php
			$counter = 0;
			foreach ( $options as $option )
			{
				?>
				<option value="<?php echo $values[$counter]; ?>"
				<?php
				if ( htmlentities( $value, ENT_QUOTES ) == $values[$counter] ) :
					echo 'selected="selected"';
				endif;
				?>
				><?php echo $option; ?></option>
				<?php
				$counter++;
			}
			?>
			</select>
			<input type="hidden" name="<?php echo $name . '_noncename'; ?>" value="<?php echo wp_create_nonce( plugin_basename(__FILE__ ) );?>" />

		</div>
	<?php
}

function get_meta_text_image( $args = array( ), $value = false ) {
	extract( $args );
	?>
	<div class="safir-metabox-item" style="margin-bottom: 20px; background:#fafafa; border:1px solid #ddd; padding: 15px">
		<p style="margin:0 0 5px 0; font-size:13px">
		<label for="<?php echo $name; ?>"><?php echo $title; ?></label>
		</p>
		<div style="position:relative; overflow:hidden; padding-bottom:5px;">
		<div style="float:left; padding-right:130px; width:100%; box-sizing:border-box"><input type="text" name="<?php echo $name; ?>" id="<?php echo $name; ?>" value="<?php echo esc_html( $value )?>" tabindex="30" style="display:block; width:100%;" />
		<button style="position:absolute; right:0; top:0; width:120px" class="button mediaButton">Resim Seç</button>
		<input type="hidden" name="<?php echo $name . '_noncename';?>" id="<?php echo $name . '_noncename';?>" value="<?php echo wp_create_nonce( plugin_basename(__FILE__) );?>" />
		</div>
	</div>
	</div>
<?php
}

function get_meta_text_textarea( $args = array( ), $value = false ) {
	extract( $args );
	?>
	<div class="safir-metabox-item" style="margin-bottom: 20px; background:#f6f6f6; border:1px solid #ddd;padding: 15px">
		<p style="margin:0; font-size:13px">
		<label for="<?php echo $name; ?>"><?php echo $title; ?></label>
		</p>
		<p>
		<textarea name="<?php echo $name; ?>" id="<?php echo $name; ?>" tabindex="30" style="display:block; width:100%"><?php echo esc_html( $value )?></textarea>
		<input type="hidden" name="<?php echo $name . '_noncename';?>" id="<?php echo $name . '_noncename';?>" value="<?php echo wp_create_nonce( plugin_basename(__FILE__) );?>" />
		</p>
	</div>
<?php
}

function safir_save_meta_data( $post_id ) {
	global $post;
	if (isset($_POST['post_type']) && "post" == $_POST['post_type'] && get_option('slcode') )
	{

		$meta_boxes = array_merge( safir_post_meta_boxes( ) );
		foreach ( $meta_boxes as $meta_box )
		{
			if ( !wp_verify_nonce( $_POST[$meta_box['name']."_noncename"], plugin_basename(__FILE__ ) ) )
			{
				return $post_id;
			}
			if ( "page" == $_POST['post_type'] && !current_user_can( "edit_page", $post_id ) )
			{
				return $post_id;
			}
			if ( "post" == $_POST['post_type'] && !current_user_can( "edit_post", $post_id ) )
			{
				return $post_id;
			}
			$data = stripslashes( $_POST[$meta_box['name']] );
			if ( get_post_meta( $post_id, $meta_box['name'] ) == "" )
			{
				add_post_meta( $post_id, $meta_box['name'], $data, true );
			}
			else if ( $data != get_post_meta( $post_id, $meta_box['name'], true ) )
			{
				update_post_meta( $post_id, $meta_box['name'], $data );
			}
			else if ( $data == "" )
			{
				delete_post_meta( $post_id, $meta_box['name'], get_post_meta( $post_id, $meta_box['name'], true ) );
			}
		}
	}

}

function safir_create_meta_box() {
	add_meta_box( "safir-meta-boxes", 'Diğer Bilgiler', "post_meta_boxes", "post", "normal", "high" );
}

add_action( "add_meta_boxes", "safir_create_meta_box" );
add_action( "save_post", "safir_save_meta_data" );

